#!/bin/bash
#

# build_mysql_client.sh

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <e10|e13|e14|e15|e17|e19|c2|c5|c7> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=mysql_client
origpkgver=v5_5_62
pkgver=${origpkgver}
ssibuildshims_version=v1_04_12
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=mysql-${pkgdotver}

get_this_dir

get_ssibuildshims

source define_basics NO_TYPE

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

case ${basequal} in
  e1[045])
    cc=gcc
    cxx=g++
    cxxflg="-std=c++14 -Wno-deprecated-declarations"
    ;;
  e1[79])
    cc=gcc
    cxx=g++
    cxxflg="-std=c++17 -Wno-deprecated-declarations -Wno-error=register"
    ;;
  e13)
    cc=clang
    cxx=clang++
    cxxflg="-std=c++14 -Wno-deprecated-declarations"
     ;;
  c[257])
    cc=clang
    cxx=clang++
    cxxflg="-std=c++17 -Wno-deprecated-declarations -Wno-error=register"
    ;;
  *)
    ssi_die "Unable to recognize base qualifier ${basequal}"
esac

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual} || ssi_die "fake declare failed"

setup ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "fake setup failed."

# We need cmake
source ${SSIBUILDSHIMS_DIR}/bin/setup_cmake || ssi_die "failed to setup camke"

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`

set -x

if [ ! -d ${sourcedir}/${pkgtarname} ]
then
   cd ${sourcedir}
   tar xf ${tardir}/${pkgtarname}.tar.gz
   patch -b -p0 < ${patchdir}/${pkgtarname}.patch || ssi_die "unable to apply version-specific patch file."
fi

cd ${blddir}

CC=${cc} CXX=${cxx} CXXFLAGS=${cxxflg} cmake \
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_INSTALL_PREFIX=${pkgdir} \
  -DWITHOUT_SERVER:BOOL=ON \
  ${sourcedir}/${pkgtarname} || \
ssi_die "CMake failed."
make -j ${ncore} ${DEBUG_BUILD:+VERBOSE=1} || ssi_die "make failed."
make install || ssi_die "make install failed."

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi
if [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS}
echo "mysql_client is installed at ${MYSQL_CLIENT_DIR}"

# fix mysql_config
mv ${MYSQL_CLIENT_FQ_DIR}/bin/mysql_config ${MYSQL_CLIENT_FQ_DIR}/bin/mysql_config.bak
cat ${MYSQL_CLIENT_FQ_DIR}/bin/mysql_config.bak | sed "s%${MYSQL_CLIENT_FQ_DIR}%\${MYSQL_CLIENT_FQ_DIR}%g" > ${MYSQL_CLIENT_FQ_DIR}/bin/mysql_config
chmod +x ${MYSQL_CLIENT_FQ_DIR}/bin/mysql_config


# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
